# ProductRatePlanChargeObjectNSFieldsItemTypeNS

Type of item that is created in NetSuite for the product rate plan charge. Only available if you have installed the [Zuora Connector for NetSuite](https://www.zuora.com/connect/app/?appId=265). 

## Enum

* `INVENTORY` (value: `'Inventory'`)

* `NON_INVENTORY` (value: `'Non Inventory'`)

* `SERVICE` (value: `'Service'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


